CustomerSelectionDatasource class

Constructors

CustomerSelectionDatasource({required String baseUrl, required String businessId, LittleFishHttpClient? client, LoggerService? logger})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

addCustomer({required Customer customer}) Future<Customer>
getCustomers() Future<List<Customer>>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited